==> haskell-httpd-shed-0.4.0.3-27-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-httpd-shed.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: httpd-shed
version: 0.4.0.3
id: httpd-shed-0.4.0.3-BDTDvtPreI880Lu1VZ2rNt
key: httpd-shed-0.4.0.3-BDTDvtPreI880Lu1VZ2rNt
license: BSD-3-Clause
copyright: (c) 2009 Andy Gill
maintainer: Andy Gill
author: Andy Gill, Brandon Moore, Henning Thielemann, John Van Enk.
synopsis: A simple web-server with an interact style API
description:
    This web server promotes a Request to IO Response function
    into a local web server. The user can decide how to interpret
    the requests, and the library is intended for implementing Ajax APIs.
category: Network, Web
abi: 50f12b1a5725d9d5d4a453f718f10b8c
exposed: True
exposed-modules:
    Network.Shed.Httpd
import-dirs: /usr/lib/ghc-8.4.3/site-local/httpd-shed-0.4.0.3
library-dirs: /usr/lib/ghc-8.4.3/site-local/httpd-shed-0.4.0.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/httpd-shed-0.4.0.3
hs-libraries: HShttpd-shed-0.4.0.3-BDTDvtPreI880Lu1VZ2rNt
depends:
    base-4.11.1.0 network-2.7.0.1-BCOaRvxEBr5QkpBn67mFr
    network-uri-2.6.1.0-AstEwZoXrlUJQq4VkxaVo9
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             network-2.7.0.1-BCOaRvxEBr5QkpBn67mFr=64a54c687aa7806d1b651ff4086a22e3
             network-uri-2.6.1.0-AstEwZoXrlUJQq4VkxaVo9=1c5b19d707f7ce4714ffa81cd536dbf4
haddock-interfaces: /usr/share/doc/haskell-httpd-shed/html/httpd-shed.haddock
haddock-html: /usr/share/doc/haskell-httpd-shed/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-httpd-shed-0.4.0.3-28-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-httpd-shed.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: httpd-shed
version: 0.4.0.3
id: httpd-shed-0.4.0.3-DgaL2w3BMzSe1X7Jow1f2
key: httpd-shed-0.4.0.3-DgaL2w3BMzSe1X7Jow1f2
license: BSD-3-Clause
copyright: (c) 2009 Andy Gill
maintainer: Andy Gill
author: Andy Gill, Brandon Moore, Henning Thielemann, John Van Enk.
synopsis: A simple web-server with an interact style API
description:
    This web server promotes a Request to IO Response function
    into a local web server. The user can decide how to interpret
    the requests, and the library is intended for implementing Ajax APIs.
category: Network, Web
abi: 2ab585b14ec60cd1cca5ec3d75f8e4ed
exposed: True
exposed-modules:
    Network.Shed.Httpd
import-dirs: /usr/lib/ghc-8.4.3/site-local/httpd-shed-0.4.0.3
library-dirs: /usr/lib/ghc-8.4.3/site-local/httpd-shed-0.4.0.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/httpd-shed-0.4.0.3
hs-libraries: HShttpd-shed-0.4.0.3-DgaL2w3BMzSe1X7Jow1f2
depends:
    base-4.11.1.0 network-2.7.0.2-DrojrvFSQxn3NIxU0DhiNK
    network-uri-2.6.1.0-AstEwZoXrlUJQq4VkxaVo9
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             network-2.7.0.2-DrojrvFSQxn3NIxU0DhiNK=94d8930bfafd62e59b581d22ac71f05d
             network-uri-2.6.1.0-AstEwZoXrlUJQq4VkxaVo9=1c5b19d707f7ce4714ffa81cd536dbf4
haddock-interfaces: /usr/share/doc/haskell-httpd-shed/html/httpd-shed.haddock
haddock-html: /usr/share/doc/haskell-httpd-shed/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
